## Recommended Reading Order

***

### Prelude (i): I'm new to Python

_It's recommended that readers are familiar with Python built-ins:_

- Your first program: Hello World
- Data types: Integers, Floats, Lists, Tuples, Strings, etc.
- Math operations: Addition, subtraction, multiplication, exponentiation, etc.
- Logic operators: "==", "!=", ">","is", "not", "and", etc.
- Code Blocks: If-elif-else, while, for
- Built-ins: Functions and libraries
- Functions: Basic structure, arguments, documentation, style

_Optionally:_

- Classes: Instantiation, objects, overloading

### Prelude (ii): I'm familiar with vanilla Python

_It's recommended that readers are familiar with science oriented libraries:_

- NumPy

_Optionally:_

- SciPy

### Level 0: CARPy - basic

_Readers are introduced to the basic data structures of CARPy:_

- Quantity and Unit Conversions

_Optionally:_

- Constants for Engineers

### Level 1: CARPy - intermediate

_Readers learn how to interface with basic methods of CARPy's component modules:_

- Atmosphere Models
- Engine Performance Decks
- Modelling Aerofoil Sections
- Predicting Wing Lift and Drag

Optionally:

- Airfield Properties
- Compressible Gas Dynamics

### ~~Level 2: CARPy - advanced~~ [coming soon]

_Readers learn how to carry out advanced concept analysis with CARPy:_

- Coming soon...
